pub struct KalmanFilter<'a> {
pub model: &'a StateSpaceModel,
}Fields
model: &'a StateSpaceModelImplementations
Sourceimpl<'a> KalmanFilter<'a>
impl<'a> KalmanFilter<'a>
pub fn new(model: &'a StateSpaceModel) -> Self
Sourcepub fn filter(
&self,
observations: &Array1<f64>,
a0: Option<Array1<f64>>,
p0: Option<Array2<f64>>,
) -> Result<KalmanFilterResult>
pub fn filter( &self, observations: &Array1<f64>, a0: Option<Array1<f64>>, p0: Option<Array2<f64>>, ) -> Result<KalmanFilterResult>
Performs exact Forward Kalman Filtering with optional Diffuse State Initialization
Sourcepub fn smooth(
&self,
filter_result: &KalmanFilterResult,
) -> Result<SmootherResult>
pub fn smooth( &self, filter_result: &KalmanFilterResult, ) -> Result<SmootherResult>
Rauch-Tung-Striebel (RTS) Backward Smoother Pass Computes conditional state distributions given ALL observations: a_{t|N} and P_{t|N}